;; Generated package description from a68-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "a68-mode" "1.3.0.20260614.1" "Major mode for editing Algol 68 code" '((emacs "24.3")) :commit "74896db77db4ce68e0022bceb3e7c73be452086c" :authors '(("Omar Polo" . "op@omarpolo.com")) :maintainer '("Jose E. Marchesi" . "jemarch@gnu.org") :keywords '("languages") :url "https://git.sr.ht/~jemarch/a68-mode")
